@@ -1,18 +1,18 @@
 #pragma once
 #include <QLatin1String>
 
-#define KWIN_PLUGIN_VERSION_STRING "6.2.5"
+#define KWIN_PLUGIN_VERSION_STRING "6.3.3"
 
 #define KWIN_BUILD_DECORATIONS 1
 #define KWIN_BUILD_KCMS 1
 #define KWIN_BUILD_NOTIFICATIONS 1
-#define KWIN_BUILD_SCREENLOCKER 0
+#define KWIN_BUILD_SCREENLOCKER 1
 #define KWIN_BUILD_TABBOX 1
 #define KWIN_BUILD_ACTIVITIES 1
 #define KWIN_BUILD_GLOBALSHORTCUTS 1
 #define KWIN_BUILD_X11 1
 constexpr QLatin1String KWIN_CONFIG("kwinrc");
-constexpr QLatin1String KWIN_VERSION_STRING("6.2.5");
+constexpr QLatin1String KWIN_VERSION_STRING("6.3.3");
 constexpr QLatin1String XCB_VERSION_STRING("1.17.0");
 constexpr QLatin1String KWIN_KILLER_BIN("/usr/local/libexec/kwin_killer_helper");
 #define HAVE_X11_XCB 1
@@ -27,10 +27,12 @@ constexpr QLatin1String KWIN_KILLER_BIN("/usr/local/libexec/kwin_killer_helper")
 #if HAVE_BREEZE_DECO
 constexpr QLatin1String BREEZE_KDECORATION_PLUGIN_ID("org.kde.breeze");
 #endif
-#define HAVE_XWAYLAND_LISTENFD 1
 #define HAVE_XWAYLAND_ENABLE_EI_PORTAL 0
 #define HAVE_GLX 1
 #define HAVE_DL_LIBRARY 0
 #define HAVE_WL_DISPLAY_SET_DEFAULT_MAX_BUFFER_SIZE 1
+#define HAVE_WL_FIXES 0
 
 constexpr QLatin1String XWAYLAND_SESSION_SCRIPTS("/etc/xdg/Xwayland-session.d");
+
+#define HAVE_LIBINPUT_INPUT_AREA 0
